@@ -1,5 +1,7 @@
 """
-Main interface for kafka service literal definitions.
+Type annotations for kafka service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/literals.html)
 
 Usage::
 
